@@ -4,7 +4,7 @@ Utility library to load the underlying json library.
 Imports `orjson` or `ujson` if either is present, otherwise it imports `json` from
 the standard library.
 """
-from json_streams.utility import types
+from json_streams import file, types
 
 
 def get_backend(backend_name: str):
@@ -30,18 +30,18 @@ dumps = backend.dumps  # type: ignore
 loads = backend.loads  # type: ignore
 
 
-def load_from_file(file_name: types.Pathlike, **kwargs):
+def load_from_file(file_name: types.Pathlike, file_mode: str = "rb", **kwargs):
     """
     Load the JSON file with the given file_name.
 
     :param file_name: name of the file to load from.
     :return: the loaded JSON file.
     """
-    with open(file_name, "br") as fp:
+    with file.open(file_name, file_mode) as fp:
         return loads(fp.read(), **kwargs)
 
 
-def dump_to_file(obj, file_name: types.Pathlike, **kwargs):
+def dump_to_file(obj, file_name: types.Pathlike, file_mode: str = "wb", **kwargs):
     """
     Dump to a JSON file with the given file name.
 
@@ -49,5 +49,5 @@ def dump_to_file(obj, file_name: types.Pathlike, **kwargs):
     :param file_name: name of the file to dump to.
     :return: anything returned from the backend.
     """
-    with open(file_name, "bw") as fp:
+    with file.open(file_name, file_mode) as fp:
         return fp.write(dumps(obj, **kwargs))
